@@ -1081,6 +1081,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             self.transaction.connect("cancellable-changed", self.on_driver_changes_cancellable_changed)
             self.transaction.connect("finished", self.on_driver_changes_finish)
             self.transaction.connect("error", self.on_driver_changes_error)
+            self.transaction.set_debconf_frontend("gnome")
             self.transaction.run()
             self.button_driver_revert.set_sensitive(False)
             self.button_driver_apply.set_sensitive(False)
@@ -1197,7 +1198,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
                         lmp = self.apt_cache[linux_meta]
                         if not lmp.is_installed:
                             self.driver_changes.append(lmp)
-        except KeyError:
+        except (AttributeError, KeyError):
             pass
 
         if button.get_active():
